==> gst-plugins-base-0.10.7.tar.bz2: gst-plugins-base-0.10.7/gst/videoscale/vs_image.h <==
/*
 * Image Scaling Functions
 * Copyright (c) 2005 David A. Schleef <ds@schleef.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __VS_IMAGE_H__
#define __VS_IMAGE_H__

#include <glib.h>

G_BEGIN_DECLS

typedef struct _VSImage VSImage;

struct _VSImage {
  guint8 *pixels;
  int width;
  int height;
  int stride;
};

void vs_image_scale_nearest_RGBA (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);
void vs_image_scale_linear_RGBA (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);

void vs_image_scale_nearest_RGB (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);
void vs_image_scale_linear_RGB (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);

void vs_image_scale_nearest_YUYV (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);
void vs_image_scale_linear_YUYV (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);

void vs_image_scale_nearest_UYVY (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);
void vs_image_scale_linear_UYVY (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);

void vs_image_scale_nearest_Y (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);
void vs_image_scale_linear_Y (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);

void vs_image_scale_nearest_RGB565 (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);
void vs_image_scale_linear_RGB565 (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);

void vs_image_scale_nearest_RGB555 (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);
void vs_image_scale_linear_RGB555 (const VSImage *dest, const VSImage *src,
    guint8 *tmpbuf);

G_END_DECLS

#endif

==> gst-plugins-base-0.10.21.tar.bz2: gst-plugins-base-0.10.21/gst/videoscale/vs_image.h <==
/*
 * Image Scaling Functions
 * Copyright (c) 2005 David A. Schleef <ds@schleef.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __VS_IMAGE_H__
#define __VS_IMAGE_H__

#include <liboil/liboil-stdint.h>

typedef struct _VSImage VSImage;

struct _VSImage {
  uint8_t *pixels;
  int width;
  int height;
  int stride;
};

void vs_image_scale_nearest_RGBA (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);
void vs_image_scale_linear_RGBA (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);

void vs_image_scale_nearest_RGB (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);
void vs_image_scale_linear_RGB (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);

void vs_image_scale_nearest_YUYV (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);
void vs_image_scale_linear_YUYV (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);

void vs_image_scale_nearest_UYVY (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);
void vs_image_scale_linear_UYVY (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);

void vs_image_scale_nearest_Y (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);
void vs_image_scale_linear_Y (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);

void vs_image_scale_nearest_RGB565 (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);
void vs_image_scale_linear_RGB565 (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);

void vs_image_scale_nearest_RGB555 (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);
void vs_image_scale_linear_RGB555 (const VSImage *dest, const VSImage *src,
    uint8_t *tmpbuf);

#endif
